import { AxiosResponse, Axios, AxiosRequestConfig, AxiosRequestTransformer, AxiosResponseTransformer } from 'axios';

interface ApiResponseError$1 {
    error?: any;
    errors?: {
        [key: string]: any;
    };
}
declare type RawResponse$1<T> = AxiosResponse<T | ApiResponseError$1>;

declare type AxiosPost = typeof Axios.prototype.post;
declare type AxiosGet = typeof Axios.prototype.get;
declare type AxiosDelete = typeof Axios.prototype.delete;
declare type AxiosPatch = typeof Axios.prototype.patch;
declare type ResponseInterceptor = Parameters<typeof Axios.prototype.interceptors.response.use>;
declare type RequestInterceptor = Parameters<typeof Axios.prototype.interceptors.request.use>;
declare class AxiosApi {
    private defaultConfig;
    private axios;
    constructor(config?: AxiosRequestConfig);
    post<T>(...args: Parameters<AxiosPost>): Promise<ApiResponseError$1 | T>;
    get<T>(...args: Parameters<AxiosGet>): Promise<ApiResponseError$1 | T>;
    delete<T>(...args: Parameters<AxiosDelete>): Promise<ApiResponseError$1 | T>;
    patch<T>(...args: Parameters<AxiosPatch>): Promise<ApiResponseError$1 | T>;
    addRequestInterceptor(...options: RequestInterceptor): void;
    addResponseInterceptor(...options: ResponseInterceptor): void;
}

/**
 *
 * @param data request data
 * @param headers request headers
 * @returns
 */
declare const jsonRequest: AxiosRequestTransformer;
/**
 *
 * @param data response data
 * @param headers response headers
 * @returns properly parsed data
 */
declare const jsonResponse: AxiosResponseTransformer;
/**
 *
 * @param response the raw AxiosResponse which contains a `data` property
 * @returns Just the data, properly typed as T | {error, errors}
 */
declare function responseHandler<T = unknown>({ data }: RawResponse$1<T>): T | ApiResponseError$1;

interface ApiResponseError {
    error?: any;
    errors?: {
        [key: string]: any;
    };
}
declare type RawResponse<T> = AxiosResponse<T | ApiResponseError>;
declare type ApiResponse<T> = T | ApiResponseError;

export { ApiResponse, ApiResponseError, AxiosApi, AxiosDelete, AxiosGet, AxiosPatch, AxiosPost, RawResponse, RequestInterceptor, ResponseInterceptor, jsonRequest, jsonResponse, responseHandler };
